@@ -4,13 +4,14 @@
 :Synopsis:          This module is used by pytest to verify that messages function properly
 :Created By:        Jeff Shurtliff
 :Last Modified:     Jeff Shurtliff
-:Modified Date:     26 Sep 2022
+:Modified Date:     30 Sep 2022
 """
 
 import os
 import sys
 
 import pytest
+import requests
 
 from . import resources
 
@@ -244,17 +245,23 @@ def test_payload_validation():
     assert payload.get('data').get('type') == 'message'
 
 
-def test_kudo_message():
+def test_kudo_message(monkeypatch):
     """This function tests the ability to kudo a message.
 
+    .. versionchanged:: 5.1.2
+       The function has been updated to use monkeypatching.
+
+    .. versionchanged:: 5.1.1
+       This function has been updated to support GitHub Workflows unit testing.
+
     .. versionadded:: 5.1.0
     """
-    if not resources.local_test_config_exists() or not resources.local_helper_exists():
-        pytest.skip("skipping local-only tests")
-
     # Instantiate the Khoros object
     set_package_path()
-    khoros_object = resources.instantiate_with_local_helper(production=False)
+    khoros_object = resources.get_core_object()
+
+    # Overwrite the requests.get functionality with the mock_post() function
+    monkeypatch.setattr(requests, 'post', resources.mock_success_post)
 
     # Perform the API call and assert that it was successful
     msg_id = '62458'    # This is a message in the Stage environment used for testing
@@ -262,17 +269,23 @@ def test_kudo_message():
     assert response.get('status') == 'success'
 
 
-def test_flagging_message():
-    """This function tests the ability to kudo a message.
+def test_flagging_message(monkeypatch):
+    """This function tests the ability to flag and unflag a message as spam.
+
+    .. versionchanged:: 5.1.2
+       The function has been updated to use monkeypatching.
+
+    .. versionchanged:: 5.1.1
+       This function has been updated to support GitHub Workflows unit testing.
 
     .. versionadded:: 5.1.0
     """
-    if not resources.local_test_config_exists() or not resources.local_helper_exists():
-        pytest.skip("skipping local-only tests")
-
     # Instantiate the Khoros object
     set_package_path()
-    khoros_object = resources.instantiate_with_local_helper(production=False)
+    khoros_object = resources.get_core_object()
+
+    # Overwrite the requests.get functionality with the mock_post() function
+    monkeypatch.setattr(requests, 'put', resources.mock_success_post)
 
     # Perform the API calls and assert that it was successful
     msg_id = '62458'    # This is a message in the Stage environment used for testing
@@ -282,17 +295,23 @@ def test_flagging_message():
     assert response.get('status') == 'success'
 
 
-def test_label_message():
+def test_label_message(monkeypatch):
     """This function tests the ability to add a label to a message.
 
+    .. versionchanged:: 5.1.2
+       The function has been updated to use monkeypatching.
+
+    .. versionchanged:: 5.1.1
+       This function has been updated to support GitHub Workflows unit testing.
+
     .. versionadded:: 5.1.0
     """
-    if not resources.local_test_config_exists() or not resources.local_helper_exists():
-        pytest.skip("skipping local-only tests")
-
     # Instantiate the Khoros object
     set_package_path()
-    khoros_object = resources.instantiate_with_local_helper(production=False)
+    khoros_object = resources.get_core_object()
+
+    # Overwrite the requests.get functionality with the mock_post() function
+    monkeypatch.setattr(requests, 'post', resources.mock_success_post)
 
     # Perform the API call and assert that it was successful
     msg_id = '62458'    # This is a message in the Stage environment used for testing
@@ -301,17 +320,23 @@ def test_label_message():
     assert response.get('status') == 'success'
 
 
-def test_tag_message():
+def test_tag_message(monkeypatch):
     """This function tests the ability to add a tag to a message.
 
+    .. versionchanged:: 5.1.2
+       The function has been updated to use monkeypatching.
+
+    .. versionchanged:: 5.1.1
+       This function has been updated to support GitHub Workflows unit testing.
+
     .. versionadded:: 5.1.0
     """
-    if not resources.local_test_config_exists() or not resources.local_helper_exists():
-        pytest.skip("skipping local-only tests")
-
     # Instantiate the Khoros object
     set_package_path()
-    khoros_object = resources.instantiate_with_local_helper(production=False)
+    khoros_object = resources.get_core_object()
+
+    # Overwrite the requests.get functionality with the mock_post() function
+    monkeypatch.setattr(requests, 'post', resources.mock_success_post)
 
     # Perform the API call and assert that it was successful
     msg_id = '62458'    # This is a message in the Stage environment used for testing
